==> nuxeo-io-manager-0.5-sources.jar: org/nuxeo/io/operation/TargetPlatform.java <==
/*
 * (C) Copyright 2014 Nuxeo SA (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Nuxeo
 */

package org.nuxeo.io.operation;

import java.io.ByteArrayInputStream;

import org.nuxeo.ecm.automation.core.annotations.Context;
import org.nuxeo.ecm.automation.core.annotations.Operation;
import org.nuxeo.ecm.automation.core.annotations.OperationMethod;
import org.nuxeo.ecm.automation.core.annotations.Param;
import org.nuxeo.ecm.core.api.Blob;
import org.nuxeo.ecm.core.api.impl.blob.InputStreamBlob;
import org.nuxeo.io.service.IoService;

import net.sf.json.JSONObject;

/**
 * @author <a href="mailto:ak@nuxeo.com">Arnaud Kervern</a>
 * @since 0.4
 */
@Operation(id = TargetPlatform.ID, category = "Io", label = "Get the target platform's definition for a specific Studio project")
public class TargetPlatform {
    public static final String ID = "Io.TargetPlatform";

    @Context
    protected IoService ioService;

    @Param(name = "symbolicName")
    protected String symbolicName;

    @OperationMethod
    public Blob run() throws Exception {
        JSONObject json = JSONObject.fromObject(ioService.getTargetPlatform(symbolicName));
        return new InputStreamBlob(new ByteArrayInputStream(
                json.toString().getBytes("UTF-8")), "application/json");
    }
}

==> nuxeo-io-manager-0.7-sources.jar: org/nuxeo/io/operation/TargetPlatform.java <==
/*
 * (C) Copyright 2014 Nuxeo SA (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Nuxeo
 */

package org.nuxeo.io.operation;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import org.codehaus.jackson.JsonGenerator;
import org.nuxeo.ecm.automation.core.annotations.Context;
import org.nuxeo.ecm.automation.core.annotations.Operation;
import org.nuxeo.ecm.automation.core.annotations.OperationMethod;
import org.nuxeo.ecm.automation.core.annotations.Param;
import org.nuxeo.ecm.core.io.marshallers.json.JsonFactoryProvider;
import org.nuxeo.io.service.IoService;

/**
 * @author <a href="mailto:ak@nuxeo.com">Arnaud Kervern</a>
 * @since 0.4
 */
@Operation(id = TargetPlatform.ID, category = "Io", label = "Get the target platform's definition for a specific Studio project")
public class TargetPlatform {
    public static final String ID = "Io.TargetPlatform";

    @Context
    protected IoService ioService;

    @Param(name = "symbolicName")
    protected String symbolicName;

    @OperationMethod
    public String run() throws IOException {
        try (OutputStream output = new ByteArrayOutputStream()) {
            try (JsonGenerator generator = JsonFactoryProvider.get().createJsonGenerator(output)) {
                generator.writeObject(ioService.getTargetPlatform(symbolicName));
            }
            return output.toString();
        }
    }
}
